@@ -5,7 +5,8 @@ from sagemaker_studio_analytics_extension.magics.sagemaker_analytics import *
 
 # This was needed for the internal methods to be discoverable from tests consistently due to builds
 # To avoid build failures because of 'Cannot find reference '_is_cluster_ldap' in '__init__.py''
-from .sagemaker_analytics import _is_cluster_ldap
+from ..resource.emr.auth import ClusterAuthUtils
+
 from .sagemaker_analytics import _get_endpoint_magic_line
 from .sagemaker_analytics import _validate_emr_args
 from .sagemaker_analytics import _get_livy_port_override
