@@ -750,7 +750,9 @@ def _initiate_connect_based_on_kernel(
 ):
     # Define livy session name. session_configs are passed to livy api.
     session_name = f"{SPARK_SESSION_NAME_PREFIX}_{uuid4().hex}"
-    conf.override(conf.session_configs.__name__, {"name": session_name})
+    session_configs = conf.session_configs()
+    session_configs["name"] = session_name
+    conf.override(conf.session_configs.__name__, session_configs)
 
     _set_logging_config()
 
